

#ifndef CAMERA_H
#define CAMERA_H
#if defined(ENABLE_DISPLAY)
#include <vector3D.h>

/**
 * \enum CameraMode
 * The different camera modes correspond to different ways to move the camera with the mouse and/or keyboard.
 */
typedef enum CameraMode
{
  FREE_CAMERA, /*!< The camera can move anywhere. */ 
  LOCKED_CAMERA /*!< The camera rotates around a fixed point. */ 
} CameraMode;


//!  Camera class. 
/*!
   There is two parameterization for the camera pose:
    - a position vector plus three vectors that must form a direct orthonormal frame for the free motion mode
    - a focus point plus three polar coordinates for the locked mode
*/
class Camera
{
  public:
   CameraMode mode; 

   //! parameters for free motion camera
   Vector3D position;  /*!< camera position (x,y,z) */
   Vector3D rightVector;  /*!< vector pointing to the right of the viewer */
   Vector3D viewDir;  /*!< vector pointing to the looking direction of the camera */
   Vector3D upVector;  /*!<  vector pointing to the upward direction of the camera */

   //! parameters for locked camera
   Vector3D focusPoint;  /*!< focus point when in locked mode */
   float radius, azimuth, elevation;  /*!< polar coordinates */
 
   float fov; /*!< field of view angle (in degrees) */

   Camera();
   void switchMode();
   void updateCartesianCoordinates();
   void render();
   void move(float x, float y, float z);
   void pan(float angle);
   void tilt(float angle);
   void zoom(float distance);
   void moveForward(float distance);
   void moveSideways(float distance);
   void changeAzimuth(float angle);
   void changeElevation(float angle);
   float distanceFromFocusPoint();
};


#endif

#endif
