
#if defined(ENABLE_DISPLAY)
#include <math.h>
#include <GL/gl.h>
#include <texture.h>
#include <stdio.h>


//! Creates a square checker-patterned texture.
//! \param _name name of the texture
//! \param size width and height (in pixels) of the texture
//! \param square_number number of squares along x (and y) direction
Texture::Texture(std::string _name, unsigned int size, unsigned int square_number)
{
  bool a, b;
  unsigned int i, j;
  float x, y;
  name= _name;
  width= size;
  height= size;

  glGenTextures(1, &genName);
  glBindTexture(GL_TEXTURE_2D, genName);
  
//   data= new unsigned char[3*width*height];
  data= new unsigned char[4*width*height];
  
  for(i=0; i<height; ++i)
  {
    for(j=0; j<width; ++j)
    {
       x= ( (float) square_number )*( (float) j )/( (float) width );
       y= ( (float) square_number )*( (float) i )/( (float) height );

       if( ((int) x)%2 == 0 )
        a= true;
       else
        a= false;

       if( ((int) y)%2 == 0 )
        b= true;
       else
        b= false;

       if(a==b)
       {       
//          data[3*j + 3*width*i]  = 0;
//          data[3*j+1 + 3*width*i]= 0;
//          data[3*j+2 + 3*width*i]= 0;
         data[4*j + 4*width*i]  = 0;
         data[4*j+1 + 4*width*i]= 0;
         data[4*j+2 + 4*width*i]= 0;
         data[4*j+3 + 4*width*i]= 128;
       }
       else
       {       
//          data[3*j + 3*width*i]  = 255;
//          data[3*j+1 + 3*width*i]= 255;
//          data[3*j+2 + 3*width*i]= 255;
         data[4*j + 4*width*i]  = 255;
         data[4*j+1 + 4*width*i]= 255;
         data[4*j+2 + 4*width*i]= 255;
         data[4*j+3 + 4*width*i]= 128;
       }
    }
  }
  
  
  //set pixel unpacking mode
  glPixelStorei(GL_UNPACK_SWAP_BYTES, 0);
  glPixelStorei(GL_UNPACK_ROW_LENGTH, 0);
  glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
  glPixelStorei(GL_UNPACK_SKIP_ROWS, 0);
  glPixelStorei(GL_UNPACK_SKIP_PIXELS, 0);
  
  //glTexImage2D (GL_TEXTURE_2D, 0, 3, width, height, 0, GL_RGB, GL_UNSIGNED_BYTE, data);
  glTexImage2D (GL_TEXTURE_2D, 0, 3, width, height, 0, GL_RGBA, GL_UNSIGNED_BYTE, data);
  
  // set texture parameters - will these also be bound to the texture???
  glTexParameterf (GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_REPEAT);
  glTexParameterf (GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_REPEAT);
  
  
  glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
  glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
}


Texture::~Texture()
{
  delete [] data;
  glDeleteTextures(1, &genName);
}

TextureList::~TextureList()
{
  std::list<Texture*>::iterator texture;

  for(texture=list.begin(); texture!=list.end(); texture++)
  {
     delete *texture;
  }

  list.clear();
}

//! Adds a new texture (for now, creates a basic checker texture).
//! \param name name of the texture to create and add to the list
//! \return 1 in case of success, 0 otherwise
int TextureList::addTexture(std::string name)
{
  Texture *texture= NULL;

  texture= new Texture(name, 400, 10);

  list.push_back(texture);

  return 1;
}

//! Selects a texture to use.
//! \param name name of the texture to select (it must belong to the list)
//! \return 1 in case of success, 0 otherwise
int TextureList::loadTexture(std::string name)
{
  std::list<Texture*>::iterator texture;
   glEnable(GL_BLEND);
    glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);
  for(texture=list.begin(); texture!=list.end(); texture++)
  {
    if(name==(*texture)->name)
    {
      glBindTexture(GL_TEXTURE_2D, (*texture)->genName);
      glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
      //glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_BLEND);
      return 1;
    }
  }

  printf("%s: %d: TextureList::loadTexture(): there is no texture named \"%s\".\n",__FILE__,__LINE__,name.c_str());
  return 0;
}
#endif
